@@ -1,22 +1,22 @@
-from gevent import monkey; monkey.patch_all()
+from gevent import monkey
+monkey.patch_all()
 import logging
 import click
 import sys
 
-from .repo import Repo
+from .config import Config
 
-pass_repo = click.make_pass_decorator(Repo, ensure=False)
+pass_config = click.make_pass_decorator(Config, ensure=False)
 
 
 @click.group()
-@click.option('--repo', required=True, help='number of greetings', type=click.Path(file_okay=False, exists=True))
-@click.option('--log-level', default='INFO', type=click.Choice(['DEBUG', 'INFO', 'WARN', 'ERROR']))
+@click.option('-c', '--config', required=True, help='config file', type=click.Path(file_okay=True, dir_okay=False, exists=True))
+@click.option('-l', '--log-level', default='INFO', type=click.Choice(['DEBUG', 'INFO', 'WARN', 'ERROR']))
 @click.pass_context
-def main(ctx, repo, log_level):
-    import sys
-    sys.path.append(repo)
+def main(ctx, config, log_level):
+    ctx.obj = Config(config)
 
-    ctx.obj = Repo(repo)
+    ctx.obj.add_home_to_pythonpath()
 
     log_level = getattr(logging, log_level)
     logging.basicConfig(level=log_level)
@@ -24,32 +24,32 @@ def main(ctx, repo, log_level):
 
 
 @main.command()
-@pass_repo
-def run(repo):
+@pass_config
+def run(config):
     click.echo("running")
 
-
     from .container import TaskContainer
     from .state import StateManager
 
-    state_manager = StateManager(repo.state_dir())
-    tasks = [repo.load_task(x) for x in repo.tasks()]
-    c = TaskContainer(tasks, state_manager)
+    state_manager = StateManager(config.state_dir())
+    tasks = [config.load_task(x) for x in config.tasks()]
+    c = TaskContainer(config.kafka_hosts, tasks, state_manager, config)
     c.run()
 
 
 @main.command()
-@pass_repo
+@pass_config
 @click.argument('dotfile', required=True, type=click.Path(file_okay=True, dir_okay=False))
-def topology(repo, dotfile):
+def topology(config, dotfile):
     click.echo("Saving topology to {0}".format(dotfile))
 
     with open(dotfile, 'w') as f:
         topics = set()
 
         print >>f, "digraph topology {"
-        for task in [repo.load_task(x) for x in repo.tasks()]:
-            print >>f, "task_{0} [label=\"{0}\", tooltip=\"{1}\", shape=box, style=bold]".format(task.name, task.description)
+        for task in [config.load_task(x) for x in config.tasks()]:
+            print >>f, "task_{0} [label=\"{0}\", tooltip=\"{1}\", shape=box, style=bold]".format(
+                task.name, task.description)
 
             for s in task.source_topics:
                 if s not in topics:
@@ -61,22 +61,24 @@ def topology(repo, dotfile):
                 print >>f, "task_{0} -> topic_{1}".format(task.name, s)
 
         for topic in topics:
-            print >>f, "topic_{0} [label=\"{0}\", tooltip=\"{0} topic\", shape=ellipse, style=dashed]".format(topic)
+            print >>f, "topic_{0} [label=\"{0}\", tooltip=\"{0} topic\", shape=ellipse, style=dashed]".format(
+                topic)
 
         print >>f, "}"
 
-    click.echo("Done. You can run `dot {0}  -Tsvg -o {0}.svg` to convert it to SVG.".format(dotfile))
+    click.echo(
+        "Done. You can run `dot {0}  -Tsvg -o {0}.svg` to convert it to SVG.".format(dotfile))
 
 
 @main.command()
-@pass_repo
+@pass_config
 @click.option('--zookeeper', default='127.0.0.1')
 @click.option('--partitions', default=1)
 @click.option('--replication-factor', default=1)
-def create_topics(repo, zookeeper, partitions, replication_factor):
+def create_topics(config, zookeeper, partitions, replication_factor):
     topics = set()
 
-    for task in [repo.load_task(x) for x in repo.tasks()]:
+    for task in [config.load_task(x) for x in config.tasks()]:
         topics.update(task.source_topics)
         topics.update(task.result_topics)
 
@@ -84,6 +86,7 @@ def create_topics(repo, zookeeper, partitions, replication_factor):
     for topic in sorted(topics):
         print "./bin/kafka-topics.sh --zookeeper {zookeeper} --create --topic {topic} --replication-factor {replication_factor} --partitions {partitions}".format(**locals())
 
+
 @main.command()
 @click.argument('task_name')
 def reset(task_name):
@@ -94,26 +97,28 @@ def reset(task_name):
     # seeking to 0
     # starting
 
+
 @main.command()
-@pass_repo
-def topics(repo):
+@pass_config
+def topics(config):
     topics = set()
 
-    for task in [repo.load_task(x) for x in repo.tasks()]:
+    for task in [config.load_task(x) for x in config.tasks()]:
         topics.update(task.source_topics)
         topics.update(task.result_topics)
 
     for t in sorted(topics):
         print t
 
-@main.command()
-@pass_repo
-@click.argument('task')
-def offsets(repo, task):
 
-    task = repo.load_task(task)
+@main.command()
+@pass_config
+@click.argument('task')
+def offsets(config, task):
+
+    task = config.load_task(task)
     from .state import StateManager
-    state_manager = StateManager(repo.state_dir())
+    state_manager = StateManager(config.state_dir())
     ostore = state_manager.get_offset_store(task)
 
     from pymza.offset import SimpleOffsetTracker
@@ -125,24 +130,25 @@ def offsets(repo, task):
 
 
 @main.command()
+@click.option('--kafka', default="localhost:9092")
 @click.argument('topic')
-def topic_tail(topic):
+def topic_tail(kafka, topic):
     from kafka import KafkaClient, SimpleConsumer
 
-    # To send messages synchronously
-    kafka = KafkaClient("localhost:9092")
+    kafka = KafkaClient(kafka)
 
-    # To consume messages
-    consumer = SimpleConsumer(kafka, "my-group", str(topic), auto_commit=False, max_buffer_size=10*1024*1024)
+    consumer = SimpleConsumer(
+        kafka, "my-group", str(topic), auto_commit=False, max_buffer_size=10 * 1024 * 1024)
     consumer.provide_partition_info()
     consumer.seek(0, 0)
-    click.echo("Tailing {0}, {1} messages pending".format(topic, consumer.pending()))
+    click.echo(
+        "Tailing {0}, {1} messages pending".format(topic, consumer.pending()))
     for partition, message in consumer:
         print 'k:', message.message.key
         print 'v:', message.message.value
         print
 
-    kafka.close()    
+    kafka.close()
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
