@@ -9,17 +9,19 @@ logger = logging.getLogger('pymza.container')
 
 class TaskContainer(object):
 
-    def __init__(self, tasks, state_manager):
+    def __init__(self, kafka_hosts, tasks, state_manager, repo):
         self.tasks = tasks
         self.state_manager = state_manager
-        self.kafka = KafkaClient("localhost:9092")
+        self.kafka = KafkaClient(kafka_hosts)
+        self.repo = repo
 
     def run(self):
         tasks = [
             Task(self.kafka,
                  task,
                  self.state_manager.get_state(task),
-                 self.state_manager.get_offset_store(task)
+                 self.state_manager.get_offset_store(task),
+                 self.repo.task_config(task.name)
                  )
             for task in self.tasks]
 
