@@ -15,13 +15,10 @@ from .offset import SimpleOffsetTracker, WindowedOffsetTracker
 
 
 class TaskCode(object):
-    def __init__(self, code):
+    def __init__(self, name, code):
+        self.name = name
         self.code = code
 
-    @property
-    def name(self):
-        return self.code.TASK_NAME
-
     @property
     def description(self):
         return self.code.__doc__
@@ -44,6 +41,11 @@ class TaskCode(object):
         if val is not None:
             return float(val)
 
+    def init(self, config):
+        if not hasattr(self.code, 'init'):
+            return
+        return self.code.init(config)
+
     def process(self, message, state):
         return self.code.process(message, state)
 
@@ -53,7 +55,7 @@ class TaskCode(object):
 
 class Task(object):
 
-    def __init__(self, kafka, code, state, offset_store):
+    def __init__(self, kafka, code, state, offset_store, config):
         self.kafka = kafka
         self.code = code
         self.producer = KeyedProducer(self.kafka)
@@ -63,12 +65,25 @@ class Task(object):
         self.logger = logging.getLogger('pymza.task.{0}'.format(self.name))
         self.queue = Queue(maxsize=1000)
         self.last_commit = time.time()
-        self.commit_time = IntervalTracker(5)
+        self.config = config
+
+        commit_interval = 5
+        try:
+            commit_interval = int(config.get('commit_interval'))
+        except (TypeError, ValueError):
+            pass
+        self.commit_time = IntervalTracker(commit_interval)
+
+        window_interval = self.code.window_interval
+        try:
+            window_interval = int(config.get('window_interval'))
+        except (TypeError, ValueError):
+            pass
 
         self.result_topics = set(self.code.result_topics)
 
         if self.code.is_windowed:
-            self.window_time = IntervalTracker(self.code.window_interval)
+            self.window_time = IntervalTracker(window_interval)
             self.offsets = WindowedOffsetTracker()
         else:
             self.window_time = None
@@ -83,6 +98,7 @@ class Task(object):
         return self.code.source_topics
 
     def run(self):
+        self.code.init(self.config)
         self.offset_store.load(self.offsets)
 
         consumers = []
