@@ -30,9 +30,9 @@ data = [
     ('422657598488186881', 'http://t.co/4S2IzfcZIO'),
 ]
 
-for i in range(10):
-    for tweet_id, url in data:
-        producer.send('tweet_urls', tweet_id, json.dumps(dict(tweet_id=tweet_id, url=url)))
+#for i in range(10):
+for tweet_id, url in data:
+    producer.send('tweet_urls', tweet_id, json.dumps(dict(tweet_id=tweet_id, url=url)))
 
 producer.stop(timeout=10)
 kafka.close()
